@@ -67,9 +67,15 @@ class ExternalBinary:
         self.extract = extract
         self.exec_name = exec_name
 
-    def download(self):
+    def _binary(self):
         path = Path(os.getenv("KUBECTL_DOWNLOAD_DIR") or click.get_app_dir(APP_NAME))
-        binary = path / "{}-{}".format(self.name, self.version)
+        return path / "{}-{}".format(self.name, self.version)
+
+    def exists(self):
+        return self._binary().exists()
+
+    def download(self):
+        binary = self._binary()
 
         if not binary.exists():
             try:
@@ -83,7 +89,7 @@ class ExternalBinary:
             arch = "amd64"  # FIXME: hardcoded value
             url = self.url_template.format(version=self.version, os=platform, arch=arch)
             with Action("Downloading {} {}...".format(self.name, self.version)) as act:
-                response = requests.get(url)
+                response = requests.get(url, timeout=30)
                 response.raise_for_status()
 
                 data = response.content
